==> ae_transfer_service-0.1.1.tar.gz: ae_transfer_service-0.1.1/README.md <==
<!--
  THIS FILE IS EXCLUSIVELY MAINTAINED IN THE NAMESPACE ROOT PACKAGE. CHANGES HAVE TO BE DONE THERE.
  All changes will be deployed automatically to all the portions of this namespace package.
-->
# transfer_service portion of ae namespace package

[![GitLabPipeline](https://img.shields.io/gitlab/pipeline/ae-group/ae_transfer_service/master?logo=python)](
    https://gitlab.com/ae-group/ae_transfer_service)
[![PyPIVersion](https://img.shields.io/pypi/v/ae_transfer_service)](
    https://pypi.org/project/ae-transfer-service/#history)

>The portions (modules and sub-packages) of the Application Environment for Python are within
the `ae` namespace and are providing helper methods and classes for to develop
full-featured applications with Python.

[![Coverage](https://ae-group.gitlab.io/ae_transfer_service/coverage.svg)](
    https://ae-group.gitlab.io/ae_transfer_service/coverage/ae_transfer_service_py.html)
[![MyPyPrecision](https://ae-group.gitlab.io/ae_transfer_service/mypy.svg)](
    https://ae-group.gitlab.io/ae_transfer_service/lineprecision.txt)
[![PyLintScore](https://ae-group.gitlab.io/ae_transfer_service/pylint.svg)](
    https://ae-group.gitlab.io/ae_transfer_service/pylint.log)

[![PyPIImplementation](https://img.shields.io/pypi/implementation/ae_transfer_service)](
    https://pypi.org/project/ae-transfer-service/)
[![PyPIPyVersions](https://img.shields.io/pypi/pyversions/ae_transfer_service)](
    https://pypi.org/project/ae-transfer-service/)
[![PyPIWheel](https://img.shields.io/pypi/wheel/ae_transfer_service)](
    https://pypi.org/project/ae-transfer-service/)
[![PyPIFormat](https://img.shields.io/pypi/format/ae_transfer_service)](
    https://pypi.org/project/ae-transfer-service/)
[![PyPIStatus](https://img.shields.io/pypi/status/ae_transfer_service)](
    https://libraries.io/pypi/ae-transfer-service)
[![PyPIDownloads](https://img.shields.io/pypi/dm/ae_transfer_service)](
    https://pypi.org/project/ae-transfer-service/#files)


## installation


Execute the following command for to use the ae.transfer_service module in your
application. It will install ae.transfer_service into your python (virtual) environment:
 
```shell script
pip install ae-transfer-service
```

If you instead want to contribute to this portion then first fork
[the ae_transfer_service repository at GitLab](https://gitlab.com/ae-group/ae_transfer_service "ae.transfer_service code repository"),
then pull it to your machine and finally execute the following command in the root folder
of this repository (ae_transfer_service):

```shell script
pip install -e .[dev]
```

The last command will install this module portion into your virtual environment, along with
the tools you need to develop and run tests or for to extend the portion documentation.
For to contribute only to the unit tests or the documentation of this portion replace
the setup extras key `dev` in the above command with `tests` or `docs` respectively.


## namespace portion documentation

More info on the features and usage of this portion are available at
[ReadTheDocs](https://ae.readthedocs.io/en/latest/_autosummary/ae.transfer_service.html#module-ae.transfer_service
"ae_transfer_service documentation").

<!-- Common files version 0.1.66 deployed version 0.1.0 (with 0.1.66)
     to https://gitlab.com/ae-group as ae_transfer_service module as well as
     to https://ae-group.gitlab.io with CI check results as well as
     to https://pypi.org/project/ae-transfer-service as namespace portion ae-transfer-service.
-->

==> ae_transfer_service-0.2.8.tar.gz: ae_transfer_service-0.2.8/README.md <==
<!--
  THIS FILE IS EXCLUSIVELY MAINTAINED IN THE NAMESPACE ROOT PACKAGE. CHANGES HAVE TO BE DONE THERE.
-->
# transfer_service portion of ae namespace package

[![GitLabPipeline](https://img.shields.io/gitlab/pipeline/ae-group/ae_transfer_service/master?logo=python)](
    https://gitlab.com/ae-group/ae_transfer_service)
[![PyPIVersion](https://img.shields.io/pypi/v/ae_transfer_service)](
    https://pypi.org/project/ae-transfer-service/#history)

>The portions (modules and sub-packages) of the Application Environment for Python are within
the `ae` namespace and are providing helper methods and classes to develop
full-featured applications with Python.

[![Coverage](https://ae-group.gitlab.io/ae_transfer_service/coverage.svg)](
    https://ae-group.gitlab.io/ae_transfer_service/coverage/ae_transfer_service_py.html)
[![MyPyPrecision](https://ae-group.gitlab.io/ae_transfer_service/mypy.svg)](
    https://ae-group.gitlab.io/ae_transfer_service/lineprecision.txt)
[![PyLintScore](https://ae-group.gitlab.io/ae_transfer_service/pylint.svg)](
    https://ae-group.gitlab.io/ae_transfer_service/pylint.log)

[![PyPIImplementation](https://img.shields.io/pypi/implementation/ae_transfer_service)](
    https://pypi.org/project/ae-transfer-service/)
[![PyPIPyVersions](https://img.shields.io/pypi/pyversions/ae_transfer_service)](
    https://pypi.org/project/ae-transfer-service/)
[![PyPIWheel](https://img.shields.io/pypi/wheel/ae_transfer_service)](
    https://pypi.org/project/ae-transfer-service/)
[![PyPIFormat](https://img.shields.io/pypi/format/ae_transfer_service)](
    https://pypi.org/project/ae-transfer-service/)
[![PyPIStatus](https://img.shields.io/pypi/status/ae_transfer_service)](
    https://libraries.io/pypi/ae-transfer-service)
[![PyPIDownloads](https://img.shields.io/pypi/dm/ae_transfer_service)](
    https://pypi.org/project/ae-transfer-service/#files)


## installation


execute the following command to use the ae.transfer_service module in your
application. it will install ae.transfer_service into your python (virtual) environment:
 
```shell script
pip install ae-transfer-service
```

if you instead want to contribute to this portion then first fork
[the ae_transfer_service repository at GitLab](https://gitlab.com/ae-group/ae_transfer_service "ae.transfer_service code repository"),
then pull it to your machine and finally execute the following command in the root folder
of this repository (ae_transfer_service):

```shell script
pip install -e .[dev]
```

the last command will install this module portion into your virtual environment, along with
the tools you need to develop and run tests or to extend the portion documentation.
to contribute only to the unit tests or to the documentation of this portion replace
the setup extras key `dev` in the above command with `tests` or `docs` respectively.


## namespace portion documentation

more info on the features and usage of this portion are available at
[ReadTheDocs](https://ae.readthedocs.io/en/latest/_autosummary/ae.transfer_service.html#module-ae.transfer_service
"ae_transfer_service documentation").

<!-- common files version 0.2.77 deployed version 0.2.8 (with 0.2.77)
     to https://gitlab.com/ae-group as ae_transfer_service module as well as
     to https://ae-group.gitlab.io with CI check results as well as
     to https://pypi.org/project/ae-transfer-service as namespace portion ae-transfer-service.
-->
